require(beeswarm)
require(extrafont)

cols <- c("#ccccc0","#ccaa66")
df <- read.csv("Fig2b_data_INSRTemperature.csv")
df[["Epis_per_polyp"]] <- df[["Epis_per_polyp"]]/1000
df[["total_per_polyp"]] <- df[["total_per_polyp"]]/1000
df[["CellLine"]] <- factor(gsub("empty","ctrl",df[["CellLine"]]), level=c("ctrl","ecto/endo"))
df[["Sample"]] <- factor(df[["Sample"]], level =c("INSR C1-1 empty 8°C","INSR C1-1 ecto/endo 8°C","INSR C1-1 empty 12°C","INSR C1-1 ecto/endo 12°C","INSR C1-1 empty 18°C","INSR C1-1 ecto/endo 18°C","INSR C1-1 empty 22°C","INSR C1-1 ecto/endo 22°C"))
df2 <- df
df <- droplevels(df[grep("18°C|22°C", df$Sample),])



# plot Figure 2c
min <- 0
pdf("Fig2b_plot_INSRSizeTemp.pdf", family="Arial", width=3.5,height=4)
par(bty="n",mar=c(4,4,3,0))
selection <- "Epis_per_polyp"
max <- max(df[[selection]])*1.2
boxplot(data = df,
        Epis_per_polyp ~ Sample,
        names= rep(levels(df[["CellLine"]]),2),
        ylim =c(min, max),
        col=cols,
        ylab= "No. of epith. cells per polyp x1000",
        las=1,
        xlab = "INSR-HP C1-1")

# stats
print(pairwise.wilcox.test(df[[selection]], df[["Sample"]], p.adjust.method="fdr"))



# add stat indication in plot
points(c(1,2), rep(0,2), type = "l", cex=1.5)
points(c(3,4), rep(0,2), type = "l", cex=1.5)
text((x=(1:2)*2)-0.5, y=1.2, label = c("18°C","22°C"))
points(c(1,2), rep(max(df[[selection]])*1.05,2), type = "l")
points(c(1,2)+2, rep(max(df[[selection]])*1.05,2), type = "l")
text(c(1.5), rep(max(df[[selection]])*1.1), "*", cex=1.5)
text(c(3.5), rep(max(df[[selection]])*1.1), "***", cex=1.5)
dev.off()
