require(beeswarm)
require(extrafont)

cols <- c("#cccccc","#FF8080","#66CC66","#ffb380")
df <- read.csv("Fig3b_data_FoxOTemperature.csv")
df <- droplevels(df[df[["Temp"]] == 18,])
df[["Epis_per_polyp"]] <- df[["Epis_per_polyp"]]/1000
df[["total_per_polyp"]] <- df[["total_per_polyp"]]/1000
df[["CellLine"]] <- factor(gsub("empty","ctrl",df[["CellLine"]]), level=c("ctrl","endo","ecto","ecto/endo"))

min <- 0

pdf("Fig3b_plot_FoxOSize.pdf", family="Arial", width=3,height=3)
par(bty="n", mar=c(4,4,1,0))


# plot epis per polyp
selection <- "Epis_per_polyp"
max <- max(df[[selection]])*1.2

boxplot(data = df, Epis_per_polyp ~ CellLine ,ylim =c(min, max), col=cols, ylab= "No. of epith. cells per polyp x1000", xlab="FoxO-HP D11a", las=1)

# stats epis per polyp
print(pairwise.wilcox.test(df[[selection]], df[["CellLine"]], p.adjust.method="fdr"))

# indicate stats in plot
liney <- max(df[[selection]])
points(c(1,3), rep(liney,2)*1.05, type='l', cex=1.5)
text(c(2,2.5), c(liney)*c(1.1,1.2), "***", cex=1.5)
points(c(1,4), rep(liney,2)*1.15, type='l', cex=1.5)


# plot total
selection <- "total_per_polyp"
max <- max(df[[selection]])*1.2

boxplot(df[[selection]] ~ df[["CellLine"]] ,ylim =c(min, max), border="white", ylab= "No. of total cells per polyp x1000", xlab="", las=1)
beeswarm(data = df, df[[selection]] ~ df[["CellLine"]], add = T, col = cols, pch = 19, xaxt = 'n', yaxt = 'n',cex=1)
boxplot(data = df, df[[selection]] ~ df[["CellLine"]],add = T, xaxt = 'n', yaxt = 'n',outline = F, lwd=1.5)

print(pairwise.wilcox.test(df[[selection]], df[["CellLine"]], p.adjust.method="fdr"))

liney <- max(df[[selection]])
points(c(1,3), rep(liney,2)*1.05, type='l', cex=1.5)
points(c(1.85,2,2.15),rep(liney,3)*1.1, pch="*", cex=1.2)
points(c(1,4), rep(liney,2)*1.15, type='l', cex=1.5)
points(c(2.35,2.5,2.65),rep(liney,3)*1.2, pch="*", cex=1.2)

selection <- "X.Epis"
max <- max(df[[selection]])*1.2

boxplot(df[[selection]] ~ df[["CellLine"]] ,ylim =c(min, max), border="white", ylab= "Ratio total to epith. cells per polyp", xlab="", las=1)
beeswarm(data = df, df[[selection]] ~ df[["CellLine"]], add = T, col = cols, pch = 19, xaxt = 'n', yaxt = 'n',cex=1)
boxplot(data = df, df[[selection]] ~ df[["CellLine"]],add = T, xaxt = 'n', yaxt = 'n',outline = F, lwd=1.5)

print(pairwise.wilcox.test(df[[selection]], df[["CellLine"]], p.adjust.method="fdr"))


liney <- max(df[[selection]])
points(c(1,4), rep(liney,2)*1.15, type='l', cex=1.5)
points(2.5,liney*1.2, pch="*", cex=1.2)


dev.off()

par(opar)

