# Porthmeus
# 21.09.18

# load data and required packages
require(ape)
require(ggplot2)
require(extrafont)

df <- read.csv("SupFig11fg_data_ConservationBindingPocket.csv")
df[["GeneSpecies"]] <- paste(df[["Gene"]], toupper(gsub("Hydra","HAEP", df[["Species"]])), sep="_")
dd <- read.csv("SupFig11bc_data_DayhoffGBootstrap100.csv", header=F, row.names=1)
colnames(dd) <- rownames(dd)[1:19]

# calculate the Dayhoff distance to ACVL1 and ACVR1 (human)
dist <- as.data.frame(cmdscale(as.dist(dd)))
dd <- as.matrix(as.dist(dd))
dd <- as.data.frame(dd[,c("ACVL1_HUMAN","ACVR1_HUMAN")])
dd[["DDistSum"]] <- apply(dd,1,sum)


# split the data.frame into 2 frames for each inhibitor
LDN <- droplevels(df[df[["Inhibitor"]]=="LDN193189",])
K02 <- droplevels(df[df[["Inhibitor"]]=="K02288",])

LDN <- merge(LDN, dd, by.x="GeneSpecies", by.y=0)
K02 <- merge(K02, dd, by.x="GeneSpecies", by.y=0)

# plot different correlations
# start with the IC50 and the dayhoff distances

pDDLDN <- ggplot(LDN, aes(x=DDistSum, y=log10(IC50)))+
            geom_point() + 
            stat_smooth(method="lm", fullrange=T) +
            geom_vline(xintercept=LDN[grep("Hydra", LDN[["Species"]]),"DDistSum"], color="red", linetype=2)+
            theme_bw() +
            xlab("Sum of Dayhoff Distances")+
            ggtitle("LDN-193189")


pDDK02 <- ggplot(K02, aes(x=DDistSum, y=log10(IC50)))+
            geom_point() + 
            stat_smooth(method="lm", fullrange=T) +
            geom_vline(xintercept=K02[grep("Hydra", K02[["Species"]]),"DDistSum"], color="red", linetype=2)+
            theme_bw()+ 
            xlab("Sum of Dayhoff Distances")+
            ggtitle("K02288")

# plot the distance for BLOSUM62 only for the binding pocket
pB62LDN <- ggplot(LDN, aes(x=score, y=log10(IC50)))+
            geom_point() + 
            stat_smooth(method="lm", fullrange=T) +
            geom_vline(xintercept=LDN[grep("Hydra", LDN[["Species"]]),"score"], color="red", linetype=2)+
            theme_bw() +
            xlab("BLOSUM62 score")+
            ggtitle("LDN-193189")


pB62K02 <- ggplot(K02, aes(x=score, y=log10(IC50)))+
            geom_point() + 
            stat_smooth(method="lm", fullrange=T) +
            geom_vline(xintercept=K02[grep("Hydra", K02[["Species"]]),"score"], color="red", linetype=2)+
            theme_bw() +
            xlab("BLOSUM62 score")+
            ggtitle("K02288")

pdf("SupFig11bcfg_plot_Correlations.pdf", width=3, height=3, family="Arial")
print(pDDLDN)
print(pDDK02)
print(pB62LDN)
print(pB62K02)
dev.off()

# print the statistics
lmDDLDN <- lm(data = LDN, DDistSum~log10(IC50))
lmDDK02 <- lm(data = K02, DDistSum~log10(IC50))
lmB62LDN <- lm(data = LDN, score ~ log10(IC50))
lmB62K02 <- lm(data = K02, score ~ log10(IC50))

print(summary(lmDDLDN))
print(summary(lmDDK02))
print(summary(lmB62LDN))
print(summary(lmB62K02))


