# Porthmeus
# 31.10.17
require(extrafont)
require(data.table)

foxoColors <- c("#cccccc","#FF8080","#66CC66","#ffb380")
insrColors <- c("#ccccc0","#ccaa66")

# load data
dfAll <- fread("SupFig4be_data_INSRFoxOKD.csv")


# subset data to INSR-KD
df <- dfAll[Genotype == "INSR-KD C1-1",]
df[["Condition"]] <-as.factor(paste(df[["Sample"]],df[["Temperature"]],sep ="_"))
df[["Condition"]] <- factor(df[["Condition"]], levels = c("ctrl_18", "ecto/endo_18"))

# calculate values for barplot
bp <- c()
sem <- c()
for(l in levels(df[["Condition"]])){
    vals <-df[Condition == l, ddCT]
    bp <- c(bp, mean(vals))
    sem <- c(sem, sd(vals)/sqrt(length(vals)))
}

pdf("SupFig4be_plot_INSRFoxOKD.pdf", width=3,height=4, family="Arial")
par(mar= c(5,4,2,0.2))

# create the plot
barplot(-1*bp, names.arg = c("ctrl", "ecto/endo"), ylab = expression("log"[2]*"-fold-change"), xlab = "INSR-KD",ylim = c(-3,0), col = c(insrColors,insrColors[2]))

i <- 0
x <- c(0.7,1.9,3.1)
sem <- sem[c(1,2,4)]
for(b in bp[1:2]){
    i<-i+1
    points(c(x[i],x[i]),c((-1*b)-sem[i],(-1*b)+sem[i]), type = "l")
    points(c(x[i],x[i]),c((-1*b)-sem[i],(-1*b)+sem[i]), pch = 190,font=5, cex=1.3)
}

# add statistics
print(t.test(data=df, dCT~Sample))
text("**", x=1.9, y=-2.8, cex=1.3)


# subset data to FoxO-KD
df <- dfAll[Genotype == "FoxO-KD D11a",]
df[["Condition"]] <- factor(df[["Sample"]], levels = c("ctrl","endo","ecto", "ecto/endo"))

# calculate values for barplot
bp <- c()
sem <- c()
for(l in levels(df[["Condition"]])){
    vals <-df[Condition== l, ddCT]
    bp <- c(bp, mean(vals))
    sem <- c(sem, sd(vals)/sqrt(length(vals)))
}

# plot
barplot(-1*bp, names.arg = levels(df[["Condition"]]), ylab = expression("log"[2]*"-fold-change"), xlab = "FoxO-KD",ylim = c(-1.6,0), col = foxoColors)

i <- 0
x <- c(0.7,1.9,3.1,4.3)
for(b in bp){
    i<-i+1
    points(c(x[i],x[i]),c((-1*b)-sem[i],(-1*b)+sem[i]), type = "l")
    points(c(x[i],x[i]),c((-1*b)-sem[i],(-1*b)+sem[i]), pch = 190,font=5, cex=1.3)
}

# add statistics
print(pairwise.t.test(df[,ddCT], df[,Condition], p.adjust.method="BH"))
text("**", x=1.9, y=-1.4, cex=1.3)
text("***", x=3.1, y=-1.4, cex=1.3)
text("***", x=4.3, y=-1.4, cex =1.3)

dev.off()
